@@ -22,7 +22,7 @@ import pkg_resources
 
 # Define a few important constants that will be used later
 epsilon = 0.001
-c = 2.99792458E10 # cm / s
+c = 2.99792458E10  # cm / s
 sigsb = 5.6704e-5  # erg / cm^2 / s / K^4
 h = 6.62607E-27
 ang_to_cm = 1e-8
@@ -82,7 +82,8 @@ def chi_square(dat, model, uncertainty):
     return chi2
 
 
-def read_in_photometry(filename, dm, redshift, start, end, snr, mwebv, use_wc):
+def read_in_photometry(filename, dm, redshift, start, end, snr, mwebv,
+                       use_wc, verbose):
     '''
     Read in SN file
 
@@ -122,6 +123,8 @@ def read_in_photometry(filename, dm, redshift, start, end, snr, mwebv, use_wc):
     # Extract key information into seperate arrays
     phases = np.asarray(photometry_data[:, 0], dtype=float)
     errs = np.asarray(photometry_data[:, 2], dtype=float)
+    if verbose:
+        print('Getting Filter Data...')
     index = SvoFps.get_filter_index(timeout=3600)
     filterIDs = np.asarray(index['filterID'].data, dtype=str)
     wavelengthEffs = np.asarray(index['WavelengthEff'].data, dtype=float)
@@ -233,7 +236,10 @@ def generate_template(filter_wv, sn_type):
         interpolated template
     '''
 
-    my_template_file = pkg_resources.resource_filename('extrabol.template_bank', 'smoothed_sn' + sn_type + '.npz')
+    my_template_file = pkg_resources.resource_filename(
+                       'extrabol.template_bank', 'smoothed_sn' +
+                       sn_type + '.npz'
+                       )
     template = np.load(my_template_file)
     temp_times = template['time']
     temp_wavelength = template['wavelength']
@@ -278,7 +284,7 @@ def generate_template(filter_wv, sn_type):
     temp_wavelength = temp_wavelength[gis]
     temp_f_lambda = temp_f_lambda[gis]
 
-    #set peak flux to t=0
+    # Set peak flux to t=0
     peak_i = np.argmax(temp_f_lambda)
     temp_times = np.asarray(temp_times) - temp_times[peak_i]
 
@@ -447,7 +453,7 @@ def test(lc, wv_corr, z):
     return best_temp
 
 
-def interpolate(lc, wv_corr, sn_type, use_mean, z):
+def interpolate(lc, wv_corr, sn_type, use_mean, z, verbose):
     '''
     Interpolate the LC using a 2D Gaussian Process (GP)
 
@@ -485,9 +491,12 @@ def interpolate(lc, wv_corr, sn_type, use_mean, z):
     ufilts = np.unique(lc[:, 2])
     ufilts_in_angstrom = ufilts*1000.0 + wv_corr
     nfilts = len(ufilts)
-    x_pred = np.zeros((int((np.ceil(np.max(times))-np.floor(np.min(times)))+1)*nfilts, 2))
-    dense_fluxes = np.zeros((int((np.ceil(np.max(times))-np.floor(np.min(times)))+1), nfilts))
-    dense_errs = np.zeros((int((np.ceil(np.max(times))-np.floor(np.min(times)))+1), nfilts))
+    x_pred = np.zeros((int((np.ceil(np.max(times)) -
+                            np.floor(np.min(times)))+1)*nfilts, 2))
+    dense_fluxes = np.zeros((int((np.ceil(np.max(times)) -
+                                  np.floor(np.min(times)))+1), nfilts))
+    dense_errs = np.zeros((int((np.ceil(np.max(times)) -
+                                np.floor(np.min(times)))+1), nfilts))
 
     # test_y is only used if mean = True
     # but I still need it to exist either way
@@ -495,6 +504,8 @@ def interpolate(lc, wv_corr, sn_type, use_mean, z):
     test_times = []
     if use_mean:
         template = generate_template(ufilts_in_angstrom, sn_type)
+        if verbose:
+            print('Fitting Template...')
         f_stretch, t_shift, t_stretch = fit_template(ufilts_in_angstrom,
                                                      template, wv_effs,
                                                      wv_corr, fluxes, times,
@@ -512,9 +523,10 @@ def interpolate(lc, wv_corr, sn_type, use_mean, z):
         # Get Test data so that the template can be plotted
         mean = snModel()
         for i in ufilts_in_angstrom:
-            test_wv = np.full((1, round(np.max(times))
-                               - round(np.min(times))), i)
-            test_times = np.arange(round(np.min(times)), round(np.max(times)))
+            test_wv = np.full((1, int((np.ceil(np.max(times)) -
+                                       np.floor(np.min(times))))), i)
+            test_times = np.arange(int(np.floor(np.min(times))+1),
+                                   int(np.ceil(np.max(times))+1))
             test_x = np.vstack((test_times, test_wv)).T
             test_y.append(mean.get_value(test_x))
         test_y = np.asarray(test_y)
@@ -543,7 +555,8 @@ def interpolate(lc, wv_corr, sn_type, use_mean, z):
     gp.set_parameter_vector(result.x)
 
     # Populate arrays with time and wavelength values to be fed into gp
-    for jj, time in enumerate(np.arange(int(np.floor(np.min(times))), int(np.ceil(np.max(times)))+1)):
+    for jj, time in enumerate(np.arange(int(np.floor(np.min(times))),
+                                        int(np.ceil(np.max(times)))+1)):
         x_pred[jj*nfilts: jj*nfilts+nfilts, 0] = [time] * nfilts
         x_pred[jj*nfilts: jj*nfilts+nfilts, 1] = ufilts
 
@@ -588,6 +601,7 @@ def fit_bb(dense_lc, wvs, use_mcmc, T_max):
     R_arr = np.zeros(len(dense_lc))
     Terr_arr = np.zeros(len(dense_lc))
     Rerr_arr = np.zeros(len(dense_lc))
+    prior_fit = (9000, 1e15)
 
     for i, datapoint in enumerate(dense_lc):
         fnu = 10.**((-datapoint[:, 0]+48.6) / -2.5)
@@ -604,11 +618,13 @@ def fit_bb(dense_lc, wvs, use_mcmc, T_max):
                 T, R = params
                 model = bbody(lam, T, R)
                 return -np.sum((f-model)**2/(f_err**2))
+
             def log_prior(params):
                 T, R = params
-                if T > 0 and T < T_max. and R > 0:
+                if T > 0 and T < T_max and R > 0:
                     return 0.
                 return -np.inf
+
             def log_probability(params, lam, f, f_err):
                 lp = log_prior(params)
                 if not np.isfinite(lp):
@@ -617,10 +633,11 @@ def fit_bb(dense_lc, wvs, use_mcmc, T_max):
 
             nwalkers = 16
             ndim = 2
-            sampler = emcee.EnsembleSampler(nwalkers, ndim, log_probability, args=[wvs,flam,flam_err])
+            sampler = emcee.EnsembleSampler(nwalkers, ndim, log_probability,
+                                            args=[wvs, flam, flam_err])
             T0 = 9000 + 1000*np.random.rand(nwalkers)
             R0 = 1e15 + 1e14*np.random.rand(nwalkers)
-            p0 = np.vstack([T0,R0])
+            p0 = np.vstack([T0, R0])
             p0 = p0.T
 
             burn_in_state = sampler.run_mcmc(p0, 100)
@@ -628,28 +645,31 @@ def fit_bb(dense_lc, wvs, use_mcmc, T_max):
             sampler.run_mcmc(burn_in_state, 4000)
             flat_samples = sampler.get_chain(discard=100, thin=1, flat=True)
 
-            T_arr[i] = np.median(flat_samples[:,0])
-            R_arr[i] = np.median(flat_samples[:,1])
-            Terr_arr[i] = (np.percentile(flat_samples[:,0], 84)-np.percentile(flat_samples[:,0], 16)) / 2.
-            Rerr_arr[i] = (np.percentile(flat_samples[:,1], 84)-np.percentile(flat_samples[:,1], 16)) / 2.
+            T_arr[i] = np.median(flat_samples[:, 0])
+            R_arr[i] = np.median(flat_samples[:, 1])
+            Terr_arr[i] = (np.percentile(flat_samples[:, 0], 84) -
+                           np.percentile(flat_samples[:, 0], 16)) / 2.
+            Rerr_arr[i] = (np.percentile(flat_samples[:, 1], 84) -
+                           np.percentile(flat_samples[:, 1], 16)) / 2.
 
         else:
+
             try:
-                BBparams, covar = curve_fit(bbody, wvs, flam, maxfev=8000,
-                                            p0=(9000, 1e15), sigma=flam_err,
+                BBparams, covar = curve_fit(bbody, wvs, flam, maxfev=10000,
+                                            p0=prior_fit, sigma=flam_err,
                                             bounds=(0, [T_max, np.inf]))
                 # Get temperature and radius, with errors, from fit
                 T_arr[i] = BBparams[0]
                 Terr_arr[i] = np.sqrt(np.diag(covar))[0]
                 R_arr[i] = np.abs(BBparams[1])
                 Rerr_arr[i] = np.sqrt(np.diag(covar))[1]
+                prior_fit = BBparams
             except RuntimeWarning:
                 T_arr[i] = np.nan
                 R_arr[i] = np.nan
                 Terr_arr[i] = np.nan
                 Rerr_arr[i] = np.nan
 
-
     return T_arr, R_arr, Terr_arr, Rerr_arr
 
 
@@ -686,7 +706,8 @@ def plot_gp(lc, dense_lc, snname, flux_corr, my_filters, wvs, test_data,
     Output
     ------
     '''
-    plot_times = np.arange(int(np.floor(np.min(lc[:,0]))), (int(np.ceil(np.max(lc[:,0])))+1))
+    plot_times = np.arange(int(np.floor(np.min(lc[:, 0]))),
+                           (int(np.ceil(np.max(lc[:, 0])))+1))
 
     # Import a color map to make the plots look pretty
     cm = plt.get_cmap('rainbow')
@@ -758,15 +779,18 @@ def plot_bb_ev(lc, Tarr, Rarr, Terr_arr, Rerr_arr, snname, outdir, sn_type):
     Output
     ------
     '''
-    interp_times = np.arange(int(np.floor(np.min(lc[:,0]))), int(np.ceil(np.max(lc[:,0])))+1)
+    interp_times = np.arange(int(np.floor(np.min(lc[:, 0]))),
+                             int(np.ceil(np.max(lc[:, 0])))+1)
     fig, axarr = plt.subplots(2, 1, sharex=True)
 
     axarr[0].plot(interp_times, Tarr / 1.e3, color='k')
-    axarr[0].fill_between(interp_times, Tarr/1.e3 - Terr_arr/1.e3, Tarr/1.e3 + Terr_arr/1.e3, color='k', alpha=0.2)
+    axarr[0].fill_between(interp_times, Tarr/1.e3 - Terr_arr/1.e3,
+                          Tarr/1.e3 + Terr_arr/1.e3, color='k', alpha=0.2)
     axarr[0].set_ylabel('Temp. (1000 K)')
 
     axarr[1].plot(interp_times, Rarr / 1e15, color='k')
-    axarr[1].fill_between(interp_times, Rarr/1e15 - Rerr_arr/1e15, Rarr/1e15 + Rerr_arr/1e15, color='k', alpha=0.2)
+    axarr[1].fill_between(interp_times, Rarr/1e15 - Rerr_arr/1e15,
+                          Rarr/1e15 + Rerr_arr/1e15, color='k', alpha=0.2)
     axarr[1].set_ylabel(r'Radius ($10^{15}$ cm)')
 
     axarr[1].set_xlabel('Time (Days)')
@@ -800,10 +824,12 @@ def plot_bb_bol(lc, bol_lum, bol_err, snname, outdir, sn_type):
     Output
     ------
     '''
-    plot_times = np.arange(int(np.floor(np.min(lc[:,0]))), int(np.ceil(np.max(lc[:,0])))+1)
+    plot_times = np.arange(int(np.floor(np.min(lc[:, 0]))),
+                           int(np.ceil(np.max(lc[:, 0])))+1)
 
     plt.plot(plot_times, bol_lum, color='k')
-    plt.fill_between(plot_times, bol_lum-bol_err, bol_lum+bol_err, color='k', alpha=0.2)
+    plt.fill_between(plot_times, bol_lum-bol_err, bol_lum+bol_err,
+                     color='k', alpha=0.2)
 
     plt.title(snname)
     plt.xlabel('Time (Days)')
@@ -852,7 +878,8 @@ def write_output(lc, dense_lc, Tarr, Terr_arr, Rarr, Rerr_arr,
     ------
     '''
 
-    times = np.arange(int(np.floor(np.min(lc[:,0]))), int(np.ceil(np.max(lc[:,0])))+1)
+    times = np.arange(int(np.floor(np.min(lc[:, 0]))),
+                      int(np.ceil(np.max(lc[:, 0])))+1)
     dense_lc = np.reshape(dense_lc, (len(dense_lc), -1))
     dense_lc = np.hstack((np.reshape(-times, (len(times), 1)), dense_lc))
     tabledata = np.stack((Tarr / 1e3, Terr_arr / 1e3, Rarr / 1e15,
@@ -874,15 +901,17 @@ def write_output(lc, dense_lc, Tarr, Terr_arr, Rarr, Rerr_arr,
                   meta={'name': 'first table'})
 
     format_dict = {head: '%0.3f' for head in table_header}
-    ascii.write(table, outdir + snname + '_' + str(sn_type) + '.txt', formats=format_dict,
-                overwrite=True)
+    ascii.write(table, outdir + snname + '_' + str(sn_type) + '.txt',
+                formats=format_dict, overwrite=True)
 
     return 1
 
 
 def main():
 
-    default_data = pkg_resources.resource_filename('extrabol.example', 'PSc000174_extrabol.dat')
+    default_data = pkg_resources.resource_filename(
+                   'extrabol.example', 'PSc000174_extrabol.dat'
+                   )
     # Define all arguments
     parser = argparse.ArgumentParser(description='extrabol helpers')
     parser.add_argument('snfile', nargs='?',
@@ -899,8 +928,8 @@ def main():
                         help='Object luminosity distance', default=1e-5)
     parser.add_argument('-z', '--redshift', dest='redshift', type=float,
                         help='Object redshift', default=-1.)
-                        # Redshift can't =-1
-                        # this is simply a flag to be replaced later
+    # Redshift can't =-1
+    # this is simply a flag to be replaced later
     parser.add_argument('--dm', dest='dm', type=float, default=0,
                         help='Object distance modulus')
     parser.add_argument("--verbose", help="increase output verbosity",
@@ -911,8 +940,8 @@ def main():
                         type=str, default='./products/')
     parser.add_argument("--ebv", help="MWebv", dest='ebv',
                         type=float, default=-1.)
-                        # Ebv won't =-1
-                        # this is another flag to be replaced later
+    # Ebv won't =-1
+    # this is another flag to be replaced later
     parser.add_argument("--hostebv", help="Host B-V", dest='hostebv',
                         type=float, default=0.0)
     parser.add_argument('-s', '--start',
@@ -998,7 +1027,8 @@ def main():
                                                             args.start,
                                                             args.end, args.snr,
                                                             args.ebv,
-                                                            args.wvcorr)
+                                                            args.wvcorr,
+                                                            args.verbose)
 
     # Test which template fits the data best
     if sn_type == 'test':
@@ -1007,7 +1037,8 @@ def main():
         print('Using ' + str(sn_type) + ' template.')
 
     dense_lc, test_data, test_times = interpolate(lc, wv_corr, sn_type,
-                                                  mean, args.redshift)
+                                                  mean, args.redshift,
+                                                  args.verbose)
     lc = lc.T
 
     wvs, wvind = np.unique(lc[:, 2], return_index=True)
@@ -1018,6 +1049,8 @@ def main():
     # Converts to AB magnitudes
     dense_lc[:, :, 0] += flux_corr
 
+    if args.verbose:
+        print('Fitting Blackbodies, this may take a few minutes...')
     Tarr, Rarr, Terr_arr, Rerr_arr = fit_bb(dense_lc, wvs, args.mc, args.T_max)
 
     # Calculate bolometric luminosity and error
@@ -1032,7 +1065,8 @@ def main():
             print('Making plots in ' + args.outdir)
         plot_gp(lc, dense_lc, snname, flux_corr, ufilts, wvs, test_data,
                 args.outdir, sn_type, test_times, mean, args.template)
-        plot_bb_ev(lc, Tarr, Rarr, Terr_arr, Rerr_arr, snname, args.outdir, sn_type)
+        plot_bb_ev(lc, Tarr, Rarr, Terr_arr, Rerr_arr, snname,
+                   args.outdir, sn_type)
         plot_bb_bol(lc, bol_lum, bol_err, snname, args.outdir, sn_type)
 
     if args.verbose:
@@ -1043,4 +1077,4 @@ def main():
 
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
